| load_csv | R Documentation |
Load a CSV to Neo4J
load_csv(
on_load = "",
con,
url,
header = TRUE,
periodic_commit = 1000,
as = "csv",
type = c("row", "graph"),
output = c("r", "json"),
include_stats = TRUE,
include_meta = FALSE
)
on_load |
the code to execute on load |
con |
A NEO4JAPI connection object |
url |
the url of the csv |
header |
does the csv have a header? |
periodic_commit |
the PERIODIC COMMIT cypher arg |
as |
the AS cypher arg |
type |
Return the result as row or as graph |
output |
Use "json" if you want the output to be printed as JSON |
include_stats |
tShould the stats about the transaction be included? |
include_meta |
tShould the stats about the transaction be included? |
a csv loaded to Neo4J
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.